@@ -19,8 +19,8 @@ function(behavior,phaseX,v1,ABxlab,ABylab,ABmain){
   max=SDabove+2
   min=SDbelow-2
   
-  graphics.off()
-  layout(rbind(1,2), heights=c(6,1))
+  #graphics.off()
+  layout(rbind(1,2), heights=c(4,1))
   plot(A,ylim=c(min,max),xlim=c(0,numx),type="o",xlab=ABxlab, ylab=ABylab, main=ABmain,bty='L')
   abline(h=SDabove,col="blue")
   abline(h=SDbelow,col="red")
@@ -36,6 +36,5 @@ function(behavior,phaseX,v1,ABxlab,ABylab,ABmain){
   print(psdu)
   print(pmean)
   print(psdb)
-  ab<-NULL
-  ab<<-recordPlot()
+  
 }
